=========
Automaton
=========

.. image:: https://img.shields.io/pypi/v/automaton.svg
    :target: https://pypi.python.org/pypi/automaton/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/automaton.svg
    :target: https://pypi.python.org/pypi/automaton/
    :alt: Downloads

Friendly state machines for python.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/automaton
* Source: http://git.openstack.org/cgit/openstack/automaton
* Bugs: http://bugs.launchpad.net/automaton
